@@ -5,7 +5,7 @@ import unittest
 from typing import List
 
 from commie import iter_comments_css
-from commie._01_common import Comment
+from commie.x01_common import Comment
 
 
 def commentsToList(code: str) -> List[Comment]:
