@@ -5,7 +5,7 @@
 import unittest
 from typing import List
 
-from commie._01_common import Comment
+from commie.x01_common import Comment
 from .helper import minimize
 from .. import iter_comments_c, UnterminatedCommentError
 
